==> ordering-core-react-2.1.0.tgz: package/lib/esm/OrderProvider.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import React, { Fragment, useContext, useEffect, useState } from 'react';
import AuthContext from "./AuthContext";
import OrdersContext from "./OrdersContext";
import ConfigContext from "./ConfigContext";
import * as orderingCore from "@orderingstack/ordering-core";
export default function OrderProvider(props) {
    const _configContext = useContext(ConfigContext);
    if (!_configContext) {
        return (React.createElement(Fragment, null, "Configuration should be provided"));
    }
    const config = _configContext;
    const [orders, setOrders] = useState({});
    const { authProvider, loggedIn } = useContext(AuthContext);
    const onOrdersUpdated = (order, allOrders) => {
        //console.log("--------------" + Object.keys(allOrders).length);
        setOrders(Object.assign({}, allOrders));
    };
    function setOrderChangesListener(authProvider) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { token } = yield authProvider();
                if (token) {
                    orderingCore.orderChangesListener(config.baseUrl, config.tenant, config.venue, authProvider, onOrdersUpdated, () => {
                        setOrders({});
                    }, config.enableKDS, props.onWebsocketNotification);
                }
            }
            catch (err) {
                setOrders({});
            }
        });
    }
    useEffect(() => {
        orderingCore.setOrderStoreUpdatedCallback(onOrdersUpdated);
        setOrderChangesListener(authProvider);
    }, [loggedIn]);
    return (React.createElement(Fragment, null,
        React.createElement(OrdersContext.Provider, { value: orders }, props.children)));
}

==> ordering-core-react-2.2.0.tgz: package/lib/esm/OrderProvider.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import React, { Fragment, useContext, useEffect, useState } from 'react';
import AuthContext from "./AuthContext";
import OrdersContext from "./OrdersContext";
import ConfigContext from "./ConfigContext";
import * as orderingCore from "@orderingstack/ordering-core";
export default function OrderProvider(props) {
    const _configContext = useContext(ConfigContext);
    if (!_configContext) {
        return (React.createElement(Fragment, null, "Configuration should be provided"));
    }
    const config = _configContext;
    const [orders, setOrders] = useState({});
    const { authProvider, loggedIn } = useContext(AuthContext);
    const onOrdersUpdated = (order, allOrders) => {
        //console.log("--------------" + Object.keys(allOrders).length);
        setOrders(Object.assign({}, allOrders));
    };
    function setOrderChangesListener(authProvider) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { token } = yield authProvider();
                if (token) {
                    orderingCore.orderChangesListener(config.baseUrl, config.tenant, config.venue, authProvider, onOrdersUpdated, () => {
                        setOrders({});
                    }, config.enableKDS, props.onWebsocketNotification, props.onSteeringCommand);
                }
            }
            catch (err) {
                setOrders({});
            }
        });
    }
    useEffect(() => {
        orderingCore.setOrderStoreUpdatedCallback(onOrdersUpdated);
        setOrderChangesListener(authProvider);
    }, [loggedIn]);
    return (React.createElement(Fragment, null,
        React.createElement(OrdersContext.Provider, { value: orders }, props.children)));
}
